@@ -34,9 +34,11 @@ mod bitmap16;
 mod bitmap32;
 mod bitmap64;
 mod bitmap8;
+mod bitmap_arch;
 
 pub use bitmap128::Bitmap128;
 pub use bitmap16::Bitmap16;
 pub use bitmap32::Bitmap32;
 pub use bitmap64::Bitmap64;
 pub use bitmap8::Bitmap8;
+pub use bitmap_arch::BitmapArch;
